<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="bo">
<context>
    <name>PasswordWidget</name>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="45"/>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="128"/>
        <source>Passwords do not match</source>
        <translation>གསང་ཨང་མི་མཐུན་བ། </translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="54"/>
        <source>The hint is visible to all users. Do not include the password here.</source>
        <translation>གསང་ཨང་ཚང་མས་མཐོང་ཐུབ་པས། གསང་ཨང་གི་ཞིབ་ཕྲའི་ཆ་འཕྲིན་མ་འབྲི།</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="72"/>
        <source>New Password</source>
        <translation>གསང་ཨང་གསར་པ། </translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="94"/>
        <source>Repeat Password</source>
        <translation>གསང་ཨང་བསྐྱར་ཟློས།</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="102"/>
        <source>Password Hint</source>
        <translation>གསང་ཨང་དྲན་སྐུལ།</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="111"/>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="112"/>
        <source>Required</source>
        <translation>ངེས་པར་འབྲི་དགོས། </translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="113"/>
        <source>Optional</source>
        <translation>བདམས་ནས་བྲི་བ།</translation>
    </message>
</context>
<context>
    <name>PwqualityManager</name>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="61"/>
        <source>Password cannot be empty</source>
        <translation>གསང་ཨང་སྟོང་པ་ཡིན་མི་རུང་། </translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="62"/>
        <source>Password must have at least %1 characters</source>
        <translation>གསང་ཨང་རིང་ཚད་གྲངས་གནས་%1ལས་ཉུང་མི་རུང་།</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="63"/>
        <source>Password must be no more than %1 characters</source>
        <translation>གསང་ཨང་གི་རིང་ཚད་%1གཉིས་ལས་བརྒལ་མི་རུང་། </translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="64"/>
        <source>Password can only contain English letters (case-sensitive), numbers or special symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
        <translation>གསང་ཨང་ནི་དབྱིན་ཡིག་(ཡིག་ཆེན་དང་ཡིག་ཆུང་གི་དབྱེ་བ་འབྱེད་དགོས། )དང་། ཨང་ཀི། ཡང་ན་དམིགས་བསལ་མཚོན་རྟགས་(~!@#$%^&amp;*()[]{}\|/?,.&lt;&gt;)བཅས་ལས་གྲུབ་དགོས།</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="65"/>
        <source>No more than %1 palindrome characters please</source>
        <translation>སྐོར་ཟློས་ཡིག་འབྲུ་%1ལས་བརྒལ་མི་རུང་།</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="66"/>
        <source>No more than %1 monotonic characters please</source>
        <translation>གཅིག་རྐྱང་ཅན་གྱི་ཡིག་འབྲུ་%1ལས་བརྒལ་མི་རུང་།</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="67"/>
        <source>No more than %1 repeating characters please</source>
        <translation>བསྐྱར་ཟློས་ཡིག་འབྲུ་%1ལས་བརྒལ་མི་རུང་།</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="68"/>
        <source>The password should differ from the username</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="74"/>
        <source>Password must contain uppercase letters, lowercase letters, numbers and symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
        <translation>གསང་ཨང་ནི་ངེས་པར་དུ་ཡིག་ཆེན་དང་། ཡིག་ཆུང་། གྲངས་ཀ མཚོན་རྟགས་（~!@#$%^&amp;*-+=`|\(){}[]:;&quot;&apos;&lt;&gt;,.?/）བཅས་རིགས་བཞི་ལས་གྲུབ་དགོས།</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="75"/>
        <source>Password must not contain more than 4 palindrome characters</source>
        <translation>གསང་ཨང་ནང་བསྟུད་མར་ཟུང་ལྡན་གྱི་ཡིག་འབྲུ་4ཡན་ཡོད་མི་ཆོག </translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="76"/>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="79"/>
        <source>Do not use common words and combinations as password</source>
        <translation>གསང་ཨང་ནི་རྒྱུན་མཐོང་གི་མིང་དང་ཚིག་གྲུབ་ཡིན་མི་ཆོག </translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="77"/>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="78"/>
        <source>Create a strong password please</source>
        <translation>གསང་ཨང་སྟབས་བདེ་དྲགས་པས། གསང་ཨང་རྙོག་འཛིང་ཆེ་རུ་གཏོང་།</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="85"/>
        <source>It does not meet password rules</source>
        <translation>གསང་ཨང་བདེ་འཇགས་ཀྱི་བླང་བྱ་དང་མི་འཚམ་པ།</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/reset-password-dialog/utils.h" line="71"/>
        <source>It cannot be empty</source>
        <translation>ནང་དོན་སྟོང་པ་ཡིན་མི་རུང་།</translation>
    </message>
</context>
<context>
    <name>ResetPasswordDialog</name>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="102"/>
        <source>Resetting the password will clear the data stored in the keyring</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="104"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="160"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="207"/>
        <source>Cancel</source>
        <translation>འདོར་བ། </translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="113"/>
        <source>Security Questions</source>
        <translation>བདེ་འཇགས་གནད་དོན།</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="148"/>
        <source>Reset Password</source>
        <translation>གསང་ཨང་བསྐྱར་བཟོ།</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="149"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="192"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="195"/>
        <source>Next</source>
        <translation>རྗེས་མ། </translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="152"/>
        <source>Reset Password By UOS ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="153"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="192"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="195"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="203"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="210"/>
        <source>Reset</source>
        <translation>བསྐྱར་སྒྲིག</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="159"/>
        <source>Resetting the password will clear the data stored in your keyring, and you should log in again, please save files in advance</source>
        <translation>གསང་ཨང་བསྐྱར་སྒྲིག་བྱས་ན་ཉར་ཚགས་བྱས་པའི་གསང་ལྡེ་ཚང་མ་མེད་པར་བཟོ་བ་མ་ཟད། སྤྱོད་མཁན་གྱིས་ཡང་བསྐྱར་ཐོ་འགོད་བྱེད་དགོས་པས། སྔོན་ལ་ཡིག་ཚགས་ཉར་རྒྱུར་དོ་སྣང་བྱ་དགོས།</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="160"/>
        <source>Confirm and Reset</source>
        <translation>བསྐྱར་སྒྲིག་བྱ་རྒྱུ་གཏན་ཁེལ།</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="285"/>
        <source>Successfully reset, please log in and unlock with the new password</source>
        <translation>གསང་ཨང་བསྐྱར་སྒྲིག་ཐུབ་སོང་། གསང་ཨང་གསར་པ་སྤྱད་ནས་ཐོ་འགོད་/ཟྭ་ཕྱེ་བ་གནང་དང་།</translation>
    </message>
</context>
<context>
    <name>SecurityLevelItem</name>
    <message>
        <location filename="../src/frame/widgets/securitylevelitem.cpp" line="57"/>
        <source>Weak</source>
        <translation>ཞན་པ།</translation>
    </message>
    <message>
        <location filename="../src/frame/widgets/securitylevelitem.cpp" line="67"/>
        <source>Medium</source>
        <translation>དཀྱིལ།</translation>
    </message>
    <message>
        <location filename="../src/frame/widgets/securitylevelitem.cpp" line="77"/>
        <source>Strong</source>
        <translation>དཀའ་ཚད་མཐོ་བ།</translation>
    </message>
</context>
<context>
    <name>SecurityQuestionsWidget</name>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="109"/>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="110"/>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="111"/>
        <source>Required</source>
        <translation>ངེས་པར་འབྲི་དགོས། </translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="113"/>
        <source>What&apos;s the name of the city where you were born?</source>
        <translation>ཁྱེད་རང་སྐྱེ་སའི་གྲོང་ཁྱེར་མིང་ལ་གང་ཟེར།</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="114"/>
        <source>What&apos;s the name of the first school you attended?</source>
        <translation>ཁྱེད་ཀྱི་མ་ཡུམ་སློབ་གྲྭའི་མིང་ལ་གང་ཟེར།</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="115"/>
        <source>Who do you love the most in this world?</source>
        <translation>ཁྱེད་རང་དགའ་ཤོས་ཀྱི་མི་སུ་ཡིན།</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="116"/>
        <source>What&apos;s your favorite animal?</source>
        <translation>ཁྱེད་དགའ་ཤོས་ཀྱི་སྲོག་ཆགས་གང་རེད།</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="117"/>
        <source>What&apos;s your favorite song?</source>
        <translation>ཁྱེད་རང་དགའ་ཤོས་ཀྱི་གླུ་དབྱངས་གང་རེད།</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="118"/>
        <source>What&apos;s your nickname?</source>
        <translation>ཁྱེད་ཀྱི་མིང་འདོགས་ལ་ཅི་ཟེར།</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="168"/>
        <source>Wrong answer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="183"/>
        <source>Keep the answer under 30 characters</source>
        <translation>ལན་ཡིག་འབྲུ་30ནང་ཚུན་ཡིན་དགོས།</translation>
    </message>
</context>
<context>
    <name>UnionIDWidget</name>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="45"/>
        <source>Phone/Email</source>
        <translation>ཁ་པར་ཨང་གྲངས་/ཡིག་སྒམ་འཇུག་རོགས། </translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="51"/>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="118"/>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="267"/>
        <source>Get Code</source>
        <translation>ར་སྤྲོད་ཨང་གྲངས་ལེན་པ། </translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="71"/>
        <source>Connecting to the Internet...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="83"/>
        <source>The user account is not linked to UOS ID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="96"/>
        <source>Network disconnected, please retry after connected</source>
        <translation>དྲ་རྒྱ་ཆད་འདུག དྲ་རྒྱ་དང་འབྲེལ་མཐུད་བྱས་རྗེས་ཡང་བསྐྱར་ཚོད་ལྟ་བྱེད།</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="116"/>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="117"/>
        <source>Required</source>
        <translation>ངེས་པར་འབྲི་དགོས། </translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="158"/>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="175"/>
        <source>Phone/Email format is incorrect</source>
        <translation>ཁ་པར་ཨང་གྲངས་/ཡིག་སྒམ་གྱི་རྣམ་གཞག་ནོར་བ། </translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="229"/>
        <source>System error</source>
        <translation>མ་ལག་ནོར་བ།</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="231"/>
        <source>Login expired, please sign in to the UOS ID again</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="233"/>
        <source>Network error</source>
        <translation>དྲ་རྒྱ་ནོར་བ།</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="235"/>
        <source>You have reached the number limit to get the code today</source>
        <translation>དེ་རིང་གི་ར་སྤྲོད་ཨང་རྟགས་ལེན་ཚད་བརྒལ་སོང་།</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="236"/>
        <source>The UOS ID is not linked to a user account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="270"/>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="312"/>
        <source>Resend (%1s)</source>
        <translation>ཡང་བསྐྱར་ལེན་པ། (%1s)</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="332"/>
        <source>Failed to get the code</source>
        <translation>ར་སྤྲོད་ཨང་རྟགས་ལེན་མི་ཐུབ་པ།</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="357"/>
        <source>Wrong verification code</source>
        <translation>ར་སྤྲོད་ཨང་རྟགས་ནོར་བ། </translation>
    </message>
</context>
</TS>